docpath

# XMLRésuméLibrary: User Guide

description | Element Reference | email

## Name

docpath —

Deprecated

## Synopsis

### Content Model

    (head?,node*,tail)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.4.0. It should not be used, and will be removed in a future version.

### Parents

`docpath` may be contained in these elements: `resume`

## Examples

    <!-- TODO -->

description | Element Reference | email